////////////////////////////////////////////////////////////////////////////////
// Article: "Organizational Context Matters"                                  //
// Journal: Conflict Management and Peace Science                             //
// Author: Yasutaka Tominaga (website: yasutakatominaga.com)                  //
// Email: y-tominaga@yasutakatominaga.com                                     //
// Last updated: September 30, 2019                                           //
// Version: Stata 16                                                          //
////////////////////////////////////////////////////////////////////////////////


//* Download the replication data, "ReplicationDataSet.dta," to your folder (working directry) *//
//* The analysis is based on multiple dataset below*///
	//*Price, BC (2012) Targeting top terrorists: How leadership decapitation contributes to counterterrorism. International Security 36(4), 9–46.*//
	//Tokdemir E and Akcinaroglu S (2016) Reputation of terror groups dataset: Measuring popularity of terror groups. Journal of Peace Research 53(2): 268–277.*//
	//*Teorell J, Dahlberg S, and Holmberg S, Rothstein B, Khomenko A, and Svensson R (2017) The Quality of Government Standard Dataset, version Jan17 University of Gothenburg. The Quality of Government Institute.*//
	//*Jones SG and Libicki MC (2008) How Terrorist Groups End: Lessons for Countering al Qa’ida. Santa Monica, CA: RAND Corporation.*//
	//*Marshall MG, Gurr TD, and Jaggers T. (2018) POLITY IV PROJECT Political Regime Characteristics and Transitions, 1800-2018 Dataset Users’ Manual. Center for Systemic Peace.*//
set more off
use "`c(pwd)'/RepliDataSet.dta", clear 


/******************************Variable lists************************************/

/*ExpDecap: Leadership Targeting -- binary indicator*/
/*Ideology_Factor: Group Ideology -- categorical variable */
/*Ally: Alliance relationship among militant groups -- binary indicator */ 
/*Rival: Rival relationship among militant groups -- binary indcator */ 
/*p_polity2: Polity Score -- categorical variable*/ 
/*vdem_excrptps: Public sector corrupt -- continuous*/
/*vdem_jucorrdc: Judicial Corruption -- continuous*/
/*lnnumberkilled_1: ln(number of killed) one year lagged -- count */ 
/*lnnumberwounded_1: ln(number of wounded) one year lagged -- count */
/*intnegrep: Negative Constituency Reputatio -- cateogry */ 
/*intposrep: Positive Constituency Reputatio -- cateogry */ 
/*ffund: forced funding -- binary indicator */
/*childrec: Child recruitment -- binary indicator */ 
/*frec: Forced recruitment -- binary indicator */ 
/*pgood: Public goods -- binary indicator */
/*media: Media -- binary indicator */ 
/*politics: Political party -- binary indicator */



/******************************Main Result************************************/ 

/* Model 1 */
streg ExpDecap, dist(weibull)
est store re1

/* Model 2 */
streg ExpDecap i.Ideology_Factor Ally Rival lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re2

/* Model 3 */
streg ExpDecap i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re3
/* Figure 1 */ 
stcurve, survival at1(ExpDecap=0) at(ExpDecap=1) ytitle("Survival Rate") title("") xtitle("Organization Age") graphregion(color(white)) lpattern(solid dash) lcolor(1 black black) legend(lab(1 "Leadership Targeting") lab(2 "Non-leadership Targeting"))

/* Model 4 */
streg ExpDecap##intposrep i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re4

/* Model 5 */
streg ExpDecap##intnegrep i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re5
/* Figure 2 */ 
stcurve, survival at1(ExpDecap=1 intnegrep=1) at2(ExpDecap=1 intnegrep=2) at3(ExpDecap=1 intnegrep=3)  ytitle("Survival Rate") title("") xtitle("Organization Age") graphregion(color(white)) lpattern(solid dash dot) lcolor(1 black black black) legend(lab(1 "Targeting*Negative (1 1)") lab(2 "Targeting*Negative (1 2)") lab(3 "Targeting*Negative (1 3)")) saving(f3, replace)

/* TABLE 2 */
esttab re1 re2 re3 re4 re5, se b(3) ar2 aic star(* 0.1 ** 0.05 *** 0.01) nodepvar eform

/* Moldel 6 */
streg ExpDecap##ffund i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re6
/* Figure 2 */ 
stcurve, survival at1(ExpDecap=1 ffund=1) at1(ExpDecap=1 ffund=0) legend(lab(1 "Forced Funding") lab(2 "Non-forced Funding")) ytitle("Survival Rate") title("") xtitle("Organization Age") graphregion(color(white)) lpattern(1 solid) lpattern(2 dash) lcolor(1 black) lcolor(2 black) saving(f4a, replace)

/* Model 7 */
streg ExpDecap##childrec i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re7
/* Figure 2 */ 
stcurve, survival at1(ExpDecap=1 childrec=1) at1(ExpDecap=1 childrec=0) legend(lab(1 "Child Recruitment") lab(2 "Non-child Recruitment")) ytitle("Survival Rate") title("") xtitle("Organization Age") graphregion(color(white)) lpattern(1 solid) lpattern(2 dash) lcolor(1 black) lcolor(2 black) saving(f4b, replace)

/* Model 8 */
streg ExpDecap##frec i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re8
/* Figure 2 */ 
stcurve, survival at1(ExpDecap=1 frec=1) at1(ExpDecap=1 frec=0) legend(lab(1 "Forced Recruitment") lab(2 "Non-forced Recruitment")) ytitle("Survival Rate") title("") xtitle("Organization Age") graphregion(color(white)) lpattern(1 solid) lpattern(2 dash) lcolor(1 black) lcolor(2 black) saving(f4c, replace)

/* Model 9 */
streg ExpDecap##pgood i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re9

/* Model 10 */
streg ExpDecap##media i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re10

/* Model 11 */
streg ExpDecap##politics i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store re11

/* TABLE 3 */
esttab re6 re7 re8 re9 re10 re11, se b(3) ar2 aic star(* 0.1 ** 0.05 *** 0.01) nodepvar eform

/* Produce Figure 2 */
gr combine f3.gph f4a.gph f4b.gph f4c.gph, col(2) iscale(0.5) graphregion(color(white))




/*****Table 1******/
tab intposrep
tab intnegrep
tab politics
tab media
tab pgood
tab ffund
tab frec
tab childrec


/******************************Online Appendix************************************/ 
/* Table 1 */

sum ExpDecap i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1

/* Robustness Check */
/* Subsamlping the dataset before 2001*/
preserve 
keep if End<2001 

// Model 1
streg ExpDecap##intposrep i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o1

// Model 2
streg ExpDecap##intnegrep i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o2

// Moldel 3
streg ExpDecap##ffund i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o3

// Model 4
streg ExpDecap##childrec i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o4

// Model 5
streg ExpDecap##frec i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o5

// Model 6
streg ExpDecap##pgood i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o6

// Model 7
streg ExpDecap##media i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o7

// Model 8
streg ExpDecap##politics i.Ideology_Factor Ally Rival p_polity2 vdem_excrptps vdem_jucorrdc lnnumberkilled_1 lnnumberwounded_1, dist(weibull) robust
est store o8

/* Online Appendix: TABLE 2 */
esttab o1 o2 o3 o4 o5 o6 o7 o8, se b(3) ar2 aic star(* 0.1 ** 0.05 *** 0.01) nodepvar eform

restore













////////////////////////////////////////////END////////////////////////////////////////////
